/**
 * @module dixim
 * @submodule autoDownload
 */
dixim.namespace('dixim.autoDownload');

/**
 * @module autoDownload
 * @submodule setting-menu-dialog-view
 */

(function() {
var SettingMenuDialogView;
var prototype;
var superConstructor;
var ModalDialogView = dixim.common.ModalDialogView;
var Event = dixim.event.Event;
var _ = dixim.ctt.ResourceBundle.get;

/**
 * @class SettingMenuDialogView
 * @constructor
 * @param {Object} configs
 */
SettingMenuDialogView = function(configs) {
    ModalDialogView.call(this, configs);
};

dixim.inherit(SettingMenuDialogView, ModalDialogView);
dixim.autoDownload.SettingMenuDialogView = SettingMenuDialogView;
prototype = SettingMenuDialogView.prototype;
superConstructor = SettingMenuDialogView.superConstructor;

var SAVE_SETTING = 'saveSetting';
var FILTER_SETTING = 'filterSetting';
var SAVE_HISTORY = 'saveHistory';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.id = configs.id || '';
    configs.id = [configs.id, 'setting-menu-dialog-'].join('');

    configs.title = _('dialog_title_setting');
    configs.closeButton = dixim.proxy(this.hide, this);
    configs.buttons = [
        {text: _('dialog_close'), click: dixim.proxy(this.hide, this)},
    ];

    configs.lists = [];
    configs.lists.push({
        text: _('auto_download_setting_auto_save_setting'),
        click: dixim.proxy(this._clickSaveSetting, this),
    });
    configs.lists.push({
        text: _('auto_download_setting_filter_setting'),
        click: dixim.proxy(this._clickFilterSetting, this),
    });
    configs.lists.push({
        text: _('auto_download_setting_auto_save_history'),
        click: dixim.proxy(this._clickSaveHistory, this),
    });

    superConstructor.prototype._initialize.call(this, configs);
};

prototype._clickSaveSetting = function() {
    this.dispatchEvent(new Event(SAVE_SETTING));
};

prototype._clickFilterSetting = function() {
    this.dispatchEvent(new Event(FILTER_SETTING));
};

prototype._clickSaveHistory = function() {
    this.dispatchEvent(new Event(SAVE_HISTORY));
};

}());
