/**
 * @module dixim
 * @submodule contents
 */
dixim.namespace('dixim.contents');

/**
 * @module contents
 * @submodule transfer-reservation-edit-dialog-view
 */

(function() {
var TransferReservationEditDialogView;
var prototype;
var superConstructor;
var Event = dixim.event.Event;
var ModalDialogView = dixim.common.ModalDialogView;
var _ = dixim.ctt.ResourceBundle.get;
var $ = dixim.ctt.jQuery;
var Formatter = dixim.ctt.util.Formatter;
var Form = dixim.ctt.util.Form;

/**
 * @class TransferReservationEditDialogView
 * @extends ModalDialogView
 * @constructor
 * @param {Object} configs
 */
TransferReservationEditDialogView = function(configs) {
    ModalDialogView.call(this, configs);
};

dixim.inherit(TransferReservationEditDialogView, ModalDialogView);
dixim.contents.TransferReservationEditDialogView = TransferReservationEditDialogView;
prototype = TransferReservationEditDialogView.prototype;
superConstructor = TransferReservationEditDialogView.superConstructor;

var TEMPLATE_BODY_CONTENT = [
    '<div id="ctt-reservation-edit-description" class="dlg_main_msg">',
    '<span class="transfer-reservation-description">', '${description}', '</span>',
    '</div>',
    '<div id="reservation-date-table" class="dl_tbl">',
    '<dl>',
    '<dt id="before-reservation-date" class="reservation-date-title">',
    '<span class="before-reservation-title">', '${beforeDate}', '</span>',
    '</dt>',
    '<dd>',
    '<span class="before-reservation-data">', '${dateStr}', '</span>',
    '</dd>',
    '</dl>',
    '<dl class="none_border_bottom">',
    '<dt id="after-reservation-date" class="reservation-date-title">',
    '<span class="after-reservation-title">', '${afterDate}', '</span>',
    '</dt>',
    '<dd id="after-reservation-date-select">',
    '<label class="date_box">', '${dateSelector}', '</label>', '<br />',
    '${timeSelector}',
    '</dd>',
    '</dl>',
    '</div>',
].join('');

var EDIT = 'edit';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    var startDate;
    var dateStr;

    configs  = configs || {};

    configs.id = configs.id || '';
    configs.id = [configs.id, 'transfer-reservation-edit-dialog-'].join('');

    this._info = configs.info;

    startDate = Formatter.dcDateToDate(this._info.startTime);
    dateStr = Formatter.stringifyDate(startDate, 'YYYY/MM/DD hh/mm/ss');

    configs.title = _('contents_setting_menu_check_reservation');

    configs.bodyContent = TEMPLATE_BODY_CONTENT
        .replace('${description}', _('contents_transfer_reservation_dialog_description'))
        .replace('${beforeDate}', _('contents_transfer_reservation_dialog_before_date'))
        .replace('${dateStr}', dateStr)
        .replace('${afterDate}', _('contents_transfer_reservation_dialog_after_date'))
        .replace('${dateSelector}', Form.createDateSelector())
        .replace('${timeSelector}', Form.createTimeSelector({template: '<label class="digit_box2">${hour}</label><label class="digit_box2">${min}</label>'}));

    configs.doubleDialog = true;
    configs.buttons = [
        {
            text: _('dialog_cancel'),
            click: dixim.proxy(this.hide, this),
        },
        {
            text: _('dialog_setting'),
            click: dixim.proxy(this._clickSetting, this),
        },
    ];

    superConstructor.prototype._initialize.call(this, configs);
};

prototype._render = function() {
    var getTime = $.now();
    var date = new Date(getTime);
    var unixTime = new Date(date.getFullYear(), date.getMonth(), date.getDate()).getTime();
    var hour = date.getHours();
    var minute = date.getMinutes();

    minute = Math.ceil(minute / 10) * 10;
    minute += 10;
    if (minute >= 60) {
        minute = minute - 60;
        hour = hour + 1;
        if (hour < 0) {
            hour = 23;
        }
    }
    $('#after-reservation-date-select [name="date"]').val(unixTime);
    $('#after-reservation-date-select [name="hour"]').val(hour);
    $('#after-reservation-date-select [name="min"]').val(minute);

};

prototype.errorDialog = function() {
    this.clearDialog();
    $('#ctt-reservation-edit-description').addClass('error-text-field');
    $('#ctt-reservation-edit-description').html([
        '<span class="error-text">', _('contents_transfer_reservation_dialog_change_error_description'), '</span>',
    ].join(''));
    this.setButtons([{
        text: _('dialog_close'),
        click: dixim.proxy(this.hide, this),
    }]);
};

prototype._clickSetting = function() {
    var date = parseInt($('#after-reservation-date-select [name="date"]').val(), 10);
    var hour = parseInt($('#after-reservation-date-select [name="hour"]').val(), 10);
    var min = parseInt($('#after-reservation-date-select [name="min"]').val(), 10);

    date = new Date(date);
    date.setHours(hour, min, 0, 0);
    this.dispatchEvent(new Event(EDIT, Formatter.dateToDcDate(date)));
};

prototype.clearDialog = function() {
    this.clear();
};

}());
