/**
 * @module ctt-ad
 * @submodule auto-download-task-list-controller
 */
(function() {
var EventTarget = dixim.event.EventTarget;
var AutoDownloadApiClient = dixim.ctt.ad.AutoDownloadApiClient;
var Y = dixim.ctt.YUI;
var _ = dixim.ctt.ResourceBundle.get;
var escapeHtml = dixim.xml.escape;
var ErrorDialog = dixim.ctt.ErrorDialog;

var AutoDownloadTaskListController;
var prototype;

/**
 * Controller of Automatic Download Move-in task list.
 *
 * @class AutoDownloadTaskListController
 * @constructor
 * @param {Object} configs config object.
 * @param {String} configs.containerNode an ID of the tool container. (ex: '#container', '#wrapper')
 * @param {AutoDownloadApiClient} configs.model
 */
AutoDownloadTaskListController = function(configs) {
  EventTarget.call(this);
  this._initialize(configs);
};
dixim.inherit(AutoDownloadTaskListController, EventTarget);
dixim.ctt.ad.AutoDownloadTaskListController = AutoDownloadTaskListController;
prototype = AutoDownloadTaskListController.prototype;

var TEMPLATE_ROW_SELECTOR_CELL = '<input type="checkbox" value="${taskId}" name="rowSelector" />';

function _pow(val) {
  if (val < 10) return '0' + val;
  return '' + val;
}

var F = {
  rowSelector: function(o) {
    var record = o.record;
    var id = record.get('taskId');

    o.className += ' content-list-table-view-cell-row-selector';
    return TEMPLATE_ROW_SELECTOR_CELL.replace('${taskId}', 'task_id-' + id);
  },

  source: function(o) {
    var record = o.record;
    var source_friendly_name = escapeHtml([record.get('srcFriendlyName')].join(' '));
    var source_container_title = escapeHtml([record.get('srcContainerTitle')].join(' '));
    var source_container = [source_friendly_name,'<br>','(',source_container_title,')'].join('');

    return source_container;
  },

  destination: function(o) {
    var dst_container_path_array = o.data.dstContainerPath.split('/');
    dst_container_path_array.pop();
    var dst_current_container = dst_container_path_array.pop();

    return dst_current_container;
  },

  schedule: function(o) {
    var record = o.record;

    if (o.value === 'timed') {
      min = record.get('timedReservationStartTime');
      return [
        _pow(Math.floor(min / 60)),
        _pow(Math.floor(min % 60))
      ].join(':');
    }
    return _("ctt_table_column_label_asap");
  },

  resolution: function(o) {
    return o.value ? _('ctt_table_column_label_sd') : _('ctt_table_column_label_hd');
  },

  filterName: function(o) {
    var filter_list = [];
    var registration_filter = "";
    var query = {};
    var filter_list_length;
    var _model = new AutoDownloadApiClient();

    query.success = function(arg) {
      var data = arg.args;
      var filter_length = data.filters.length;
      var taskIds_length;

      for (var i = 0; i < filter_length; i += 1) {
        taskIds_length = data.filters[i].taskIds.length;
        for (var j = 0; j < taskIds_length; j += 1) {
          if (data.filters[i].taskIds[j] === o.data.taskId) {
            filter_list.push(data.filters[i].filterName);
          }
        }
      }
    };
    query.error = dixim.proxy(function() {
      this._showErrorDialog("ctt_error_dialog_default");
    }, this);
    query.async = false;

    _model.fetchDownloadFilterList(query);
    filter_list_length = filter_list.length;
    for (var i = 0; i < filter_list_length; i += 1) {
      registration_filter += ['・ ',filter_list[i],'<br>'].join('');
    }
    return registration_filter;
  }
};

var TEMPLATE_TABLE_CONTAINER = '<div class="yui3-skin-sam auto-download-task-list-table-view"></div>';

var COLUMNS = [
  {
    key: 'rowSelector',
    name: 'rowSelector',
    label: ' ',
    allowHTML: true,
    resizable: false,
    formatter: F.rowSelector
  },
  {
    key: 'srcContainerId',
    name: 'srcContainerId',
    label: _('ctt_table_column_label_from'),
    allowHTML: true,
    resizable: false,
    formatter: F.source
  },
  {
    key: 'dstContainerId',
    name: 'dstContainerId',
    label: _('ctt_table_column_label_to'),
    allowHTML: true,
    resizable: false,
    formatter: F.destination
  },
  {
    key: 'reservationType',
    name: 'reservationType',
    label: _('ctt_table_column_label_when'),
    allowHTML: true,
    resizable: false,
    formatter: F.schedule
  },
  {
    key: 'sdFirst',
    name: 'sdFirst',
    label: _('ctt_table_column_label_resolution'),
    allowHTML: true,
    resizable: false,
    formatter: F.resolution
  },
  {
    key: 'filterName',
    name: 'filterName',
    label: _('ctt_table_column_label_filter'),
    allowHTML: true,
    resizable: false,
    formatter: F.filterName
  }
];

function _createView() {
  var container;
  var v;

  container = Y.one(this._containerNode);
  v = Y.Node.create(TEMPLATE_TABLE_CONTAINER);
  v.setStyles({width: '100%', height: '100%'});
  v.appendTo(container);

  this._view = v;
  _createDataTable.call(this);
}

function _createDataTable() {
  var container;
  var dt;

  container = this._view;
  dt = new Y.DataTable({
    columns: COLUMNS,
    data: [],
    scrollable: "y",
    width: container.getComputedStyle('width'),
    height: container.getComputedStyle('height')
  });

  dt.onceAfter('datatable:render', _fetchTaskList, this);
  this._dataTable = dt;
}

function _fetchTaskList() {
  var fetch_task_query = {};

  fetch_task_query.success = dixim.proxy(_didFetchTaskList, this);
  fetch_task_query.error = dixim.proxy(function(e) {
    this._showErrorDialog("ctt_error_dialog_default");
  }, this);
  this._model.fetchTaskList(fetch_task_query);
}

function _didFetchTaskList(event) {
  this._dataTable.set('data', event.args.tasks);
}

function splitString(str, num) {
  var str_array = str.split("");
  var new_str = "";
  for (var i = 0; i < str_array.length; i++) {
    if (i % num === 0 && i !== 0) {
      new_str += "<br>";
    }
    new_str += str_array[i];
  }
  return new_str;
}

prototype._initialize = function(configs) {
  this._containerNode = configs.containerNode;
  this._view = null;
  this._dataTable = null;
  this._model = configs.model || new AutoDownloadApiClient();

  _createView.call(this);
};

prototype.start = function() {
  this._dataTable.render(this._view);
};

prototype.stop = function() {
};

prototype.getSelectedRows = function() {
  var dt = this._dataTable;
  var records = dt.get('data');
  var rows = [];

  records.each(function(model) {
    var sel;

    sel = ['input[name=rowSelector][value=', 'task_id-' + model.get('taskId'), ']'].join('');
    if (this._view.one(sel).get('checked')) {
      rows.push(model.getAttrs()); // TODO: exclude YUI related fields
    }
  }, this);

  return rows;
};

prototype.reload = function() {
  this._dataTable.set('data', []);
  _fetchTaskList.call(this);
};

/**
 * @method _showErrorDialog
 * @private
 * @param {String} error error ID.
 */
prototype._showErrorDialog = function(error) {
  var dialog;
  var query = {type: error};

  if (!!this._modal) {
    this._modal.destroy();
    this._modal = null;
  }
  if (typeof error.title !== "undefined") {
    query.title = error.title;
  }
  if (typeof error.description !== "undefined") {
    query.description = error.description;
  }

  dialog = new ErrorDialog(query);
  dialog.addEventListener('close', this._didCloseModalDialog, this);

  dialog.show();
  this._modal = dialog;
};

prototype._didCloseModalDialog = function(e) {
  var args = e.args;

  if (this._modal === args.dialog) {
    this._modal.destroy();
    this._modal = null;
  }
};

}());