/**
 * @module ctt
 * @submodule schedule-entry-deletion-wizard-page-controller
 */
(function() {
var Event = dixim.event.Event;
var WizardPageController = dixim.ctt.WizardPageController;
var ScheduleEntryDeletionWizardPageView = dixim.ctt.ScheduleEntryDeletionWizardPageView;
var ScheduleEntryListingController = dixim.ctt.ScheduleEntryListingController;
var ContentsTransferApiClient = dixim.ctt.api.ContentsTransferApiClient;
var _ = dixim.ctt.ResourceBundle.get;

var ScheduleEntryDeletionWizardPageController;
var prototype;
var superConstructor;

/**
 * @class ScheduleEntryDeletionWizardPageController
 * @constructor
 * @param {Object} configs
 */
ScheduleEntryDeletionWizardPageController = function(configs) {
  WizardPageController.call(this, configs);
};
dixim.inherit(ScheduleEntryDeletionWizardPageController, WizardPageController);
dixim.ctt.ScheduleEntryDeletionWizardPageController = ScheduleEntryDeletionWizardPageController;
prototype = ScheduleEntryDeletionWizardPageController.prototype;
superConstructor = ScheduleEntryDeletionWizardPageController.superConstructor;

var ErrorMessage = {
  475: _('ctt_schedule_entry_deletion_wizard_page_view_error_475'),
  476: _('ctt_schedule_entry_deletion_wizard_page_view_error_476'),
  'default': _('ctt_schedule_entry_deletion_wizard_page_view_error')
};

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
  superConstructor.prototype._initialize.call(this, configs);

  this._entryListingController = null;
  this._view = new ScheduleEntryDeletionWizardPageView();
  this._entries = null;
  this._queue = [];
  this._sessions = [];
};

/**
 * @method start
 */
prototype.start = function() {
  var v = this._view;

  v.addEventListener('cancel', this._didClickCancel, this);
  v.addEventListener('delete', this._didClickDelete, this);
  v.addEventListener('render', this._didRenderView, this);
  v.show();

  if (!!this._entryListingController) {
    this._entryListingController.start(); 
  }
  superConstructor.prototype.start.call(this);
};

prototype._didRenderView = function(e) {
  var lc;
  var w = this._wizard;
  var m;
  var entries;

  entries = w.getRegistryEntry('targetEntries');
  m = w.getRegistryEntry('model');
  m.addEventListener('removeReservation', this._didRemoveReservation, this);
  m.addEventListener('removeReservationError', this._didFailRemoveReservation, this);
  this._model = m;

  lc = new ScheduleEntryListingController({
    containerNode: this._view.getBodyContent(),
    selection: false,
    entries: entries
  });

  this._entries = entries;
  this._entryListingController = lc;
};

prototype._didClickCancel = function(e) {
  if (this._queue.length) return;
  this._exitPage();
};

prototype._didClickDelete = function(e) {
  if (this._queue.length) return;

  this._view.showActivityIndicator();

  this._queue = this._entries.concat();
  this._processDeletionQueueEntry();
};

prototype._processDeletionQueueEntry = function() {
  var queue = this._queue;
  var entry;

  if (!queue.length) {
    this._didProcessDeletionQueueEntries();
    return;
  }

  entry = queue.shift();
  this._sessions.push(this._model.removeReservation({id: entry.id}));
};

prototype._didRemoveReservation = function(e) {
  var session = e.args.session;

  dixim.array.remove(this._sessions, session);
  this._didProcessDeletionQueueEntry();
};

prototype._didFailRemoveReservation = function(e) {
  var args = e.args;
  var session = args.session;

  dixim.array.remove(this._sessions, session);
  this._view.hideActivityIndicator();
  this._view.showError(ErrorMessage[args.errorCode] || ErrorMessage['default']);
};

prototype._didProcessDeletionQueueEntry = function() {
  // TODO: update ui
  this._processDeletionQueueEntry();
};

prototype._didProcessDeletionQueueEntries = function() {
  this._exitPage();
};

prototype._exitPage = function() {
  var w = this._wizard;
  var vc;

  vc = w.popViewController();
  vc.destroy();
};

/**
 * @method stop
 */
prototype.stop = function() {
  this._stop();
  superConstructor.prototype.stop.call(this);
};

prototype._stop = function() {
  // TODO:
  if (!!this._entryListingController) {
    this._entryListingController.stop();
  }
  this._view.hide();
};

/**
 * @method destroy
 */
prototype.destroy = function() {
  var m;

  if (!!this._entryListingController) {
    this._entryListingController.destroy();
    this._entryListingController = null;
  }

  if (!!(m = this._model)) {
    m.removeEventListener('removeReservation', this._didRemoveReservation, this);
    m.removeEventListener('removeReservationError', this._didFailRemoveReservation, this);
    this._model = null;
  }
  superConstructor.prototype.destroy.call(this);
};

}());
