/**
 * @module ctt
 * @submodule schedule-entry-edit--wizard-page-controller
 */
(function() {
var Event = dixim.event.Event;
var WizardPageController = dixim.ctt.WizardPageController;
var ScheduleEntryEditWizardPageView = dixim.ctt.ScheduleEntryEditWizardPageView;
var _ = dixim.ctt.ResourceBundle.get;

var ScheduleEntryEditWizardPageController;
var prototype;
var superConstructor;

/**
 * @class ScheduleEntryEditWizardPageController
 * @extends WizardPageController
 * @constructor
 * @param {Object} configs
 */
ScheduleEntryEditWizardPageController = function(configs) {
  WizardPageController.call(this, configs);
};
dixim.inherit(ScheduleEntryEditWizardPageController, WizardPageController);
dixim.ctt.ScheduleEntryEditWizardPageController = ScheduleEntryEditWizardPageController;
prototype = ScheduleEntryEditWizardPageController.prototype;
superConstructor = ScheduleEntryEditWizardPageController.superConstructor;

// TODO:
var ErrorMessage = {
  470: _('ctt_schedule_entry_edit_wizard_page_view_error_470'),
  472: _('ctt_schedule_entry_edit_wizard_page_view_error_472'),
  475: _('ctt_schedule_entry_edit_wizard_page_view_error_475'),
  476: _('ctt_schedule_entry_edit_wizard_page_view_error_476'),
  477: _('ctt_schedule_entry_edit_wizard_page_view_error_477'),
  478: _('ctt_schedule_entry_edit_wizard_page_view_error_478'),
  'default': _('ctt_schedule_entry_edit_wizard_page_view_error')
};

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
  superConstructor.prototype._initialize.call(this, configs);
  this._view = new ScheduleEntryEditWizardPageView();
  this._session = null;
  this._model = null;
};

prototype.start = function() {
  var v = this._view;

  v.addEventListener('render', this._didRenderView, this);
  v.addEventListener('cancel', this._didClickCancel, this);
  v.addEventListener('save', this._didClickSave, this);

  superConstructor.prototype.start.call(this);
};

prototype._didRenderView = function(e) {
  var w = this._wizard;
  var m;
  var schedule;

  m = w.getRegistryEntry('model');
  m.addEventListener('updateReservation', this._didUpdateReservation, this);
  m.addEventListener('updateReservationError', this._didFailUpdateReservation, this);
  this._model = m;

  schedule = w.getRegistryEntry('targetEntries')[0];
  this._view.setTargetSchedule(schedule);
};

prototype._didClickSave = function(e) {
  var date;
  var schedule;

  if (!!this._session) return;

  this._view.showActivityIndicator();

  date = this._view.getSelectedDate();
  schedule = this._wizard.getRegistryEntry('targetEntries')[0];

  this._session = this._model.updateReservation({
    id: schedule.id,
    startTime: date
  });
};

prototype._didUpdateReservation = function(e) {
  this._view.hideActivityIndicator();
  this._session = null;
  this._exitPage();
};

prototype._didFailUpdateReservation = function(e) {
  var code = e.args.errorCode;

  this._view.hideActivityIndicator();
  this._session = null;
  this._view.showError(ErrorMessage[code] || ErrorMessage['default']);
};

prototype._didClickCancel = function(e) {
  if (!!this._session) return;
  this._cancelEdit();
};

prototype._cancelEdit = function() {
  this._exitPage();
};

prototype._exitPage = function() {
  var w = this._wizard;
  var vc;
  var m;

  m = w.getRegistryEntry('model');
  m.removeEventListener('updateReservation', this._didUpdateReservation, this);
  m.removeEventListener('updateReservationError', this._didFailUpdateReservation, this);

  vc = w.popViewController();
  vc.destroy();
};

}());
