/**
 * @module ctt
 * @submodule ctt-ad
 */
dixim.namespace('dixim.ctt.ad');

/**
 * @module ctt-ad
 * @submodule confirmation-dialog-controller
 */

(function() {
var Event = dixim.event.Event;
var EventTarget = dixim.event.EventTarget;
var ConfirmationDialogView = dixim.ctt.ad.ConfirmationDialogView;
var AutoDownloadApiClient = dixim.ctt.ad.AutoDownloadApiClient;

var ConfirmationDialogController;
var prototype;

/**
 * @class ConfirmationDialogController
 * @constructor
 * @param {Object} configs
 * @param {Object} configs.targetItems
 * @param {AutoDownloadApiClient} [configs.model]
 */
ConfirmationDialogController = function(configs) {
  EventTarget.call(this);
  this._initialize(configs);
};
dixim.inherit(ConfirmationDialogController, EventTarget);
dixim.ctt.ad.ConfirmationDialogController = ConfirmationDialogController;
prototype = ConfirmationDialogController.prototype;

/**
 * Triggered when the deletion has been done.
 *
 * @event close
 * @param {Event} event
 * @param {Object} event.args
 * @param {Object} event.args.deleted true if the deletion is completed, otherwise false.
 */
var CLOSE = 'close';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 * @param {Object} configs.targetItems
 * @param {ContentsTransferApiClient} [configs.model]
 */
prototype._initialize = function(configs) {
  configs = configs || {};

  this._view = new ConfirmationDialogView(configs);
  this._session = null;
  this._queue = [];
  this._processing = configs.processing;
  this._didFinishedFunction = configs.finish || null;
};

/**
 * @method start
 */
prototype.start = function() {
  var v = this._view;

  v.addEventListener('delete', this._didClickYes, this);
  v.addEventListener('cancel', this._didClickCancel, this);

  v.show();
};

prototype._didClickYes = function() {
  this._view.inProgress();
  this._processing();
};

prototype._didClickCancel = function() {
  if (!this._queue.length && !!!this._session) {
    this._view.destroy();
    this.dispatchEvent(new Event(CLOSE));
    return;
  }
  this._queue = [];
};

prototype._didFinish = function() {
  this._view.hideActivityIndicator();
  this._view.destroy();
  this.dispatchEvent(new Event(CLOSE));
  if (typeof this._didFinishedFunction === "function") {
    this._didFinishedFunction();
  }
};

/**
 * @method finish
 */
prototype.finish = function() {
  this._didFinish();
};

/**
 * @method stop
 */
prototype.stop = function() {
  this._view.hide();
};

/**
 * @method destroy
 */
prototype.destroy = function() {
  this._view.destroy();
};

}());
