/**
 * @module ctt
 * @submodule ctt-ad
 */
dixim.namespace('dixim.ctt.ad');

/**
 * @module ctt-ad
 * @submodule history-dialog-controller
 */

(function() {
var Event = dixim.event.Event;
var EventTarget = dixim.event.EventTarget;
var HistoryDialogView = dixim.ctt.ad.HistoryDialogView;
var AutoDownloadApiClient = dixim.ctt.ad.AutoDownloadApiClient;

var HistoryDialogController;
var prototype;

/**
 * @class HistoryDialogController
 * @constructor
 * @param {Object} configs
 * @param {AutoDownloadApiClient} [configs.model]
 */
HistoryDialogController = function(configs) {
  EventTarget.call(this);
  this._initialize(configs);
};
dixim.inherit(HistoryDialogController, EventTarget);
dixim.ctt.ad.HistoryDialogController = HistoryDialogController;
prototype = HistoryDialogController.prototype;

/**
 * Triggered when the deletion has been done.
 *
 * @event close
 * @param {Event} event
 * @param {Object} event.args
 * @param {Object} event.args.deleted true if the deletion is completed, otherwise false.
 */
var CLOSE = 'close';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 * @param {Object} configs.targetItems
 * @param {ContentsTransferApiClient} [configs.model]
 */
prototype._initialize = function(configs) {
  configs = configs || {};

  this._model = new AutoDownloadApiClient();
  this._view = new HistoryDialogView(configs);
  this._session = null;
  this._queue = [];
};

/**
 * @method start
 */
prototype.start = function() {
  var v = this._view;

  v.addEventListener('close', this._didClickClose, this);
  v.addEventListener('clear', this._didClickClear, this);

  v.show();
};

prototype._didClickClose = function() {
  this._view.destroy();
  this.dispatchEvent(new Event(CLOSE));
};

prototype._didClickClear = function() {
  this._model.deleteDownloadItemLog();
  $("#history").empty();
};

/**
 * @method destroy
 */
prototype.destroy = function() {
  this._view.destroy();
};

}());
