(function(){
/**
 * Contents Transfer Tool core module.
 *
 * @module ctt
 * @class ctt
 */
dixim.namespace('dixim.ctt');

/**
 * @property jQuery
 * @type {jQuery}
 * @static
 */
dixim.ctt.jQuery = jQuery;

/**
 * An instance of YUI.
 *
 * It is possible to refer this instance anytime,
 * however do not access property/method of this instance except <em>use()</em>
 * before the ctt initialization(init()) finished.
 *
 * Furthermore, if extra YUI modules are required,
 * please call <em>use()</em> of the instance.
 *
 *     dixim.ctt.YUI.use('some-wicked-module', function(Y) {...});
 *
 * Since this instance is shared with all ctt modules,
 * do not override this property by another YUI instance.
 *
 * @property YUI
 * @type {YUI}
 * @static
 */
dixim.ctt.YUI = typeof YUI !== 'undefined' ? YUI().use('yui-base') : null;

/**
 * Initializes the ctt module.
 *
 * The initialization process is async,
 * so this method accepts a callback function
 * that is called when the initialization finished.
 *
 * @method init
 * @static
 * @param {Function} [fn] a callback function.
 * @param {Object} [context]
 */
dixim.ctt.init = function(fn, context) {
  var c = arguments[1] || this;
  var Y = dixim.ctt.YUI;
  var f = !!fn ? dixim.proxy(fn, c) : function(){};

  if (!!Y) {
    Y.use(dixim.ctt.Configs.get('yuiModules'), f);
  } else {
    f.call(context);
  }
};

}());

/**
 * @module ctt
 * @submodule configs
 */
(function() {
var cfgs;
var DEFAULTS = {
  api: '/dms/transfer_tool/api',
  api_autodel: '/dms/ars',
  api_autocompress: '/dms/ats',
  resourceBundlePath: 'lang/',
  imagePath: 'img',
  cssPath: 'css',
  yuiModules: ['node', 'intl', 'datatype',
               'datatable-scroll', 'datatable-mutable']
};

if (typeof DIXIM_CTT_Configs === 'undefined') {
  cfgs = dixim.extend({}, DEFAULTS, true);
} else {
  cfgs = dixim.extend({}, DEFAULTS, true);
  cfgs = dixim.extend(cfgs, DIXIM_CTT_Configs, true);
}

/**
 * @class Configs
 */
dixim.ctt.Configs = {
  /**
   * @method get
   * @param {String} key
   * @return {Object}
   */
  get: function(key) {
    return cfgs[key];
  },

  /**
   * @method set
   * @param {String} key
   * @param {Object} value
   */
  set: function(key, value) {
    cfgs[key] = value;
  }
};

}());

/**
 * @module ctt
 * @submodule resource-bundle
 */
(function() {
var $ = dixim.ctt.jQuery;
var Configs = dixim.ctt.Configs;
var i18n = null;
var slice = Array.prototype.slice;

/**
 * @class ResourceBundle
 */
var ResourceBundle = {};
dixim.ctt.ResourceBundle = ResourceBundle;

/**
 * Gets a resource for the key specified.
 *
 * @method get
 * @static
 * @param {String} key
 * @param {Object} [args*]
 */
ResourceBundle.get = function() {
  var path;

  if (!!!i18n) {
    path = Configs.get('resourceBundlePath');
    if (!path.match(new RegExp('/$'))) {
      path += '/';
    }
    $.i18n.properties({
      name:'strings',
      language: 'ja',
      path: path,
      mode: 'map'
    });
    i18n = $.i18n;
  }
  return i18n.prop.apply(i18n, slice.call(arguments, 0));
};
}());
