/**
 * @module ctt
 * @submodule schedule-entry-listing-view
 */
(function() {
var ItemListingView = dixim.ctt.ItemListingView;
var Formatter = dixim.ctt.util.Formatter;
var _ = dixim.ctt.ResourceBundle.get;
var $ = dixim.ctt.jQuery;
var escapeHtml = dixim.xml.escape;

var ScheduleEntryListingView;
var superConstructor;
var prototype;

/**
 * @class ScheduleEntryListingView
 * @extends ItemListingView
 * @constructor
 * @param {Object} configs
 */
ScheduleEntryListingView = function(configs) {
  ItemListingView.call(this, configs);
};
dixim.inherit(ScheduleEntryListingView, ItemListingView);
dixim.ctt.ScheduleEntryListingView = ScheduleEntryListingView;
prototype = ScheduleEntryListingView.prototype;
superConstructor = ScheduleEntryListingView.superConstructor;

prototype._initialize = function(configs) {
  var cfg = {
    className: 'ctt-schedule-entry-listing-view',
    elementIdPrefix: 'ctt-schedule-entry-listing-view-',
    enableSelection: true,
    selectionMode: 'multiple'
  };

  cfg = dixim.extend(cfg, configs);
  this._enableSelection = cfg.enableSelection;
  superConstructor.prototype._initialize.call(this, cfg);
};

var TEMPLATE_ROW = ['<li id="${id}" class="ctt-item-listing-view-row ctt-schedule-entry-listing-view-row">',
                      '<div class="ctt-schedule-entry-listing-view-row-title">${checkboxCell} ${title}</div>',
                      '<div class="ctt-schedule-entry-listing-view-row-footer">',
                        '<span class="ctt-schedule-entry-listing-view-row-date">',
//                          '<span class="ctt-schedule-entry-listing-view-row-label">${dateLabel}</span>&nbsp;',
                          '<span class="ctt-schedule-entry-listing-view-row-value">${date}</span>',
                        '</span> - ',
                        '<span class="ctt-schedule-entry-listing-view-row-dest">',
//                          '<span class="ctt-schedule-entry-listing-view-row-label">${destLabel}</span>&nbsp;',
                          '<span class="ctt-schedule-entry-listing-view-row-value">${storage} - ${server}</span>',
                        '</span>',
                      '</div>',
                    '</li>'].join('');

var TEMPLATE_CHECKBOX_CELL = '<span class="ctt-schedule-entry-listing-view-row-checkbox"><input type="checkbox"/></span>';

/**
 * @method _createRowElementHtml
 * @param {Object} record
 * @param {Number} index
 * @protected
 */
prototype._createRowElementHtml = function(record, index) {
  var id;
  var html;
  var date;

  if (!!!(id = this._makeElementId(record))) {
    return null;
  }

  if (!!(date = record.startTime)) {
    date = Formatter.dcDateToDate(date);
    date = Formatter.stringifyDate(date);
  }

  html = TEMPLATE_ROW.
         replace('${id}', id).
         replace('${checkboxCell}', this._enableSelection ? TEMPLATE_CHECKBOX_CELL : '').
         replace('${title}', escapeHtml(record.title || '')).
//         replace('${dateLabel}', _('ctt_schedule_entry_listing_view_row_label_date')).
         replace('${date}', date || '').
//         replace('${destLabel}', _('ctt_schedule_entry_listing_view_row_label_dest')).
         replace('${server}', escapeHtml(record.server || '')).
         replace('${storage}', escapeHtml(record.storage || ''));

  return html;
};

prototype._selectRowElement = function(record) {
  var el;

  superConstructor.prototype._selectRowElement.call(this, record);
  el = this._getRowElement(record);
  $('input[type="checkbox"]', el).attr('checked', true);
};

prototype._unselectRowElement = function(record) {
  var el;

  superConstructor.prototype._unselectRowElement.call(this, record);
  el = this._getRowElement(record);
  $('input[type="checkbox"]', el).attr('checked', false);
};

}());
