/**
 * @module dixim
 * @submodule contents
 */
dixim.namespace('dixim.contents');

/**
 * @module contents
 * @submodule mkdir-dialog-view
 */
(function() {
var MkdirDialogView;
var prototype;
var superConstructor;
var Event = dixim.event.Event;
var ModalDialogView = dixim.common.ModalDialogView;
var _ = dixim.ctt.ResourceBundle.get;
var $ = dixim.ctt.jQuery;

/**
 * @class MkdirDialogView
 * @extends ModalDialogView
 * @constructor
 * @param {Object} configs
 */
MkdirDialogView = function(configs) {
    ModalDialogView.call(this, configs);
};

dixim.inherit(MkdirDialogView, ModalDialogView);
dixim.contents.MkdirDialogView = MkdirDialogView;
prototype = MkdirDialogView.prototype;
superConstructor = MkdirDialogView.superConstructor;

var MKDIR = 'mkdir';

var TEMPLATE_BODY_CONTENT = [
    '<div class="dlg_main_msg">', '${desc}',
    '<div id="mkdirErrorField">', '</div>',
    '</div>',
    '<div class="dl_tbl">',
    '<dl class="none_border_bottom">',
    '<dt>', '${mkdirName}', '</dt>',
    '<dd>', '<input id="mkdirName" type="text" maxlength="255" />', '</dd>',
    '</dl>',
    '</div>',
].join('');

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    var buttons;
    var bodyContent;

    configs  = configs || {};

    configs.id = configs.id || '';
    configs.id = [configs.id, 'mkdir-dialog'].join('');

    configs.title = _('contents_operation_menu_mkdir');
    configs.buttons = [
        {
            text: _('dialog_cancel'),
            click: dixim.proxy(this.hide, this)
        },
        {
            text: _('dialog_make'),
            click: dixim.proxy(this._clickMkdir, this)
        },
    ];

    configs.bodyContent = TEMPLATE_BODY_CONTENT
        .replace('${desc}', _('contents_mkdir_description'))
        .replace('${mkdirName}', _('contents_mkdir_new_name'));

    superConstructor.prototype._initialize.call(this, configs);
};

prototype.error = function(text) {
    $('#mkdirErrorField').html([
        '<span class="error-text">', text, '</span>',
    ].join(''));
};

prototype._clickMkdir = function() {
    this.dispatchEvent(new Event(MKDIR, {name: $('#mkdirName').val()}));
};

}());
