/**
 * @module dixim
 * @submodule contents
 */
dixim.namespace('dixim.contents');

/**
 * @module contents
 * @submodule move-dialog-view
 */
(function() {
var MoveDialogView;
var prototype;
var superConstructor;
var Event = dixim.event.Event;
var ModalDialogView = dixim.common.ModalDialogView;
var _ = dixim.ctt.ResourceBundle.get;
var $ = dixim.ctt.jQuery;
var Configs = dixim.ctt.Configs;

/**
 * @class MoveDialogView
 * @extends ModalDialogView
 * @constructor
 * @param {Object} configs
 */
MoveDialogView = function(configs) {
    ModalDialogView.call(this, configs);
};

dixim.inherit(MoveDialogView, ModalDialogView);
dixim.contents.MoveDialogView = MoveDialogView;
prototype = MoveDialogView.prototype;
superConstructor = MoveDialogView.superConstructor;

var SELECT_DIRECTORY = 'selectDirectory';
var MOVE = 'move';

var TEMPLATE_BODY_CONTENT = [
    '<div class="dlg_main_msg">', '${desc}', '</div>',
    '<div id="contentsList" class="list-field dlg_scroll list_next">',
    '<table>', '</table>',
    '</div>',
].join('');

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    var buttons;
    var bodyContent;

    configs  = configs || {};

    configs.id = configs.id || '';
    configs.id = [configs.id, 'move-dialog'].join('');

    configs.title = _('contents_operation_menu_move');
    configs.buttons = [
        {
            text: _('dialog_cancel'),
            click: dixim.proxy(this.hide, this)
        },
        {
            text: _('dialog_move'),
            click: dixim.proxy(this._clickMove, this)
        },
    ];
    configs.contentHeight = '300px';

    configs.bodyContent = TEMPLATE_BODY_CONTENT
        .replace('${desc}', _('contents_move_description'));

    this._dstInfoList = [];

    superConstructor.prototype._initialize.call(this, configs);
};

prototype.addRow = function(content) {
    var rowSelector;

    $('#contentsList table').append([
        '<tr>',
        '<td class="select-server-checkbox">',
        '<label class="select-pointer">', '<input type="checkbox">', '<span>', '</span>', '</label>',
        '</td>',
        '<td class="select-directory">',
        '<img src="', Configs.get('imagePath'), '/ico_list_folder.png', '" width="40px">',
        '<span class="info-title-text">', content.title, '</span>',
        '</td>',
        '</tr>',
    ].join(''));
    rowSelector = $('#contentsList table tr:last-child');

    rowSelector.find('td').not('.select-server-checkbox').on('click', content, dixim.proxy(this._clickDirectory, this));
    rowSelector.find('[type="checkbox"]').on('click', content, dixim.proxy(this._clickCheckbox, this));
};

prototype.noRow = function() {
    this.error(_('contents_move_fetch_no_contents'));
};

prototype.error = function(text) {
    $('#contentsList').html([
        '<div class="error-text-field txt_none">', 
        '<span>', text, '</span>',
        '</div>',
    ].join(''));
};

prototype.changeCheckbox = function() {
    var checkboxSelector = $('#contentsList table [type="checkbox"]:checked');

    if (checkboxSelector.length === 1) {
        this.enableButton(_('dialog_move'));
    } else {
        this.disableButton(_('dialog_move'));
    }
};

prototype._clickDirectory = function(e) {
    this.dispatchEvent(new Event(SELECT_DIRECTORY, e.data));
};

prototype._clickCheckbox = function(e) {
    this.changeCheckbox();
    if (e.currentTarget.checked) {
        this._dstInfoList.push(e.data);
    } else {
        for (var i = 0, len = this._dstInfoList.length; i < len; i += 1) {
            if (this._dstInfoList[i].id === e.data.id) {
                this._dstInfoList.splice(i, 1);
                break;
            }
        }
    }
};

prototype.cleanList = function() {
    $('#contentsList').html(['<table>', '</table>'].join(''));
};

prototype._clickMove = function() {
    this.dispatchEvent(new Event(MOVE, {dst: this._dstInfoList[0]}));
};

}());
